@@ -10,5 +10,9 @@ def uuid1():
     return str(uuid.uuid1())
 
 
+def millis(s):
+    return s * 1000
+
+
 def seconds(ms):
     return ms / 1000
